camelot.view.action_steps — Camelot documentation

### Navigation

- index
- modules |
- Camelot documentation »
- Module code »

# Source code for camelot.view.action_steps

    #  ============================================================================
    #
    #  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
    #  www.conceptive.be / project-camelot@conceptive.be
    #
    #  This file is part of the Camelot Library.
    #
    #  This file may be used under the terms of the GNU General Public
    #  License version 2.0 as published by the Free Software Foundation
    #  and appearing in the file license.txt included in the packaging of
    #  this file.  Please review this information to ensure GNU
    #  General Public Licensing requirements will be met.
    #
    #  If you are unsure which license is appropriate for your use, please
    #  visit www.python-camelot.com or contact project-camelot@conceptive.be
    #
    #  This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
    #  WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
    #
    #  For use of this library in commercial applications, please contact
    #  project-camelot@conceptive.be
    #
    #  ============================================================================

    from change_object import ChangeObject, ChangeObjects
    from gui import OpenFormView, Refresh, ShowChart, ShowPixmap
    from open_file import OpenFile, OpenStream, OpenString, OpenJinjaTemplate
    from orm import CreateObject, DeleteObject, FlushSession, UpdateObject
    from print_preview import PrintHtml, PrintPreview, PrintJinjaTemplate
    from select_file import SelectFile
    from update_progress import UpdateProgress

    __all__ = [
        ChangeObject.__name__,
        ChangeObjects.__name__,
        CreateObject.__name__,
        DeleteObject.__name__,
        FlushSession.__name__,
        OpenFile.__name__,
        OpenFormView.__name__,
        OpenJinjaTemplate.__name__,
        OpenStream.__name__,
        OpenString.__name__,
        PrintHtml.__name__,
        PrintJinjaTemplate.__name__,
        PrintPreview.__name__,
        Refresh.__name__,
        SelectFile.__name__,
        ShowChart.__name__,
        ShowPixmap.__name__,
        UpdateObject.__name__,
        UpdateProgress.__name__,
        ]

### Navigation

- index
- modules |
- Camelot documentation »
- Module code »

Comments
blog comments powered by Disqus